import { OperationObject, PathsObject, DefinitionsObject } from '@loopback/openapi-spec';
export interface ControllerSpec {
    /**
     * The base path on which the Controller API is served.
     * If it is not included, the API is served directly under the host.
     * The value MUST start with a leading slash (/).
     */
    basePath?: string;
    /**
     * The available paths and operations for the API.
     */
    paths: PathsObject;
    /**
     * JSON Schema definitions of models used by the controller
     */
    definitions?: DefinitionsObject;
}
/**
 * Data structure for REST related metadata
 */
export interface RestEndpoint {
    verb: string;
    path: string;
    spec?: OperationObject;
}
/**
 * Get the controller spec for the given class
 * @param constructor Controller class
 */
export declare function getControllerSpec(constructor: Function): ControllerSpec;
