"use strict";
// Copyright IBM Corp. 2018. All Rights Reserved.
// Node module: @loopback/openapi-v2
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
function jsonToSchemaObject(jsonDef) {
    const json = jsonDef; // gets around index signature error
    const result = {};
    const propsToIgnore = [
        'anyOf',
        'oneOf',
        'additionalItems',
        'defaultProperties',
        'typeof',
    ];
    for (const property in json) {
        if (propsToIgnore.includes(property)) {
            continue;
        }
        switch (property) {
            case 'type': {
                if (json.type === 'array' && !json.items) {
                    throw new Error('"items" property must be present if "type" is an array');
                }
                result.type = Array.isArray(json.type) ? json.type[0] : json.type;
                break;
            }
            case 'allOf': {
                result.allOf = _.map(json.allOf, item => jsonToSchemaObject(item));
                break;
            }
            case 'definitions': {
                result.definitions = _.mapValues(json.definitions, def => jsonToSchemaObject(def));
                break;
            }
            case 'properties': {
                result.properties = _.mapValues(json.properties, item => jsonToSchemaObject(item));
                break;
            }
            case 'additionalProperties': {
                if (typeof json.additionalProperties !== 'boolean') {
                    result.additionalProperties = jsonToSchemaObject(json.additionalProperties);
                }
                break;
            }
            case 'items': {
                const items = Array.isArray(json.items) ? json.items[0] : json.items;
                result.items = jsonToSchemaObject(items);
                break;
            }
            case 'enum': {
                const newEnum = [];
                const primitives = ['string', 'number', 'boolean'];
                for (const element of json.enum) {
                    if (primitives.includes(typeof element) || element === null) {
                        newEnum.push(element);
                    }
                    else {
                        // if element is JsonDefinition, convert to SchemaObject
                        newEnum.push(jsonToSchemaObject(element));
                    }
                }
                result.enum = newEnum;
                break;
            }
            default: {
                result[property] = json[property];
                break;
            }
        }
    }
    return result;
}
exports.jsonToSchemaObject = jsonToSchemaObject;
//# sourceMappingURL=json-to-schema.js.map