import { ParameterObject, SchemaObject, ParameterLocation, ItemsObject } from '@loopback/openapi-spec';
/**
 * Describe an input parameter of a Controller method.
 *
 * `@param` can be applied to method itself or specific parameters. For example,
 * ```
 * class MyController {
 *   @get('/')
 *   @param(offsetSpec)
 *   @param(pageSizeSpec)
 *   list(offset?: number, pageSize?: number) {}
 * }
 * ```
 * or
 * ```
 * class MyController {
 *   @get('/')
 *   list(
 *     @param(offsetSpec) offset?: number,
 *     @param(pageSizeSpec) pageSize?: number,
 *   ) {}
 * }
 * ```
 * Please note mixed usage of `@param` at method/parameter level is not allowed.
 *
 * @param paramSpec Parameter specification.
 */
export declare function param(paramSpec: ParameterObject): (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
export declare namespace param {
    const query: {
        string: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        number: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        integer: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        boolean: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
    };
    const header: {
        string: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        number: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        integer: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        boolean: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
    };
    const path: {
        string: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        number: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        integer: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        boolean: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
    };
    const formData: {
        string: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        number: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        integer: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
        boolean: (name: string) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
    };
    /**
     * Define a parameter that's set to the full request body.
     *
     * @param name Parameter name
     * @param schema The schema defining the type used for the body parameter.
     */
    const body: (name: string, schema?: SchemaObject | undefined) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
    /**
     * Define a parameter of `array` type
     *
     * @example
     * ```ts
     * export class MyController {
     *   @get('/greet')
     *   greet(@param.array('names', 'query', 'string') names: string[]): string {
     *     return `Hello, ${names}`;
     *   }
     * }
     * ```
     * @param name Parameter name
     * @param source Source of the parameter value
     * @param itemSpec Item type for the array or the full item object
     */
    const array: (name: string, source: ParameterLocation, itemSpec: "string" | "number" | "boolean" | "integer" | "array" | ItemsObject) => (target: Object, member: string | symbol, descriptorOrIndex: number | TypedPropertyDescriptor<any>) => void;
}
